@@ -1,5 +1,5 @@
 package Amazon::DynamoDB::20120810;
-$Amazon::DynamoDB::20120810::VERSION = '0.10';
+$Amazon::DynamoDB::20120810::VERSION = '0.11';
 use strict;
 use warnings;
 
@@ -490,6 +490,7 @@ sub query {
 
     foreach my $key_name (keys %{$args{KeyConditions}}) {
         my $key_details = $args{KeyConditions}->{$key_name};
+        ref($key_details) eq 'HASH' || Carp::confess("KeyConditions for key $key_name are not a hashref");
         my $compare_op = $key_details->{ComparisonOperator} // 'EQ';
         $compare_op =~ /^(EQ|LE|LT|GE|GT|BEGINS_WITH|BETWEEN)$/
             || Carp::confess("Unknown comparison operator specified: $compare_op");
@@ -773,9 +774,12 @@ my $encode_key = sub {
     my $r;
     foreach my $k (keys %$source) {
         my $v = $source->{$k};	
-        # There is no sense in encoding undefined values.
-        if (defined($v)) {
-            $r->{$k} = { _encode_type_and_value($v) };
+        # There is no sense in encoding undefined values or values that 
+        # are the empty string.
+        if (defined($v) && $v ne '') {
+            # Reference $source->{$k} since the earlier test may cause
+            # the value to be stringified.
+            $r->{$k} = { _encode_type_and_value($source->{$k}) };
         }
     }
     return $r;
@@ -1016,7 +1020,7 @@ Amazon::DynamoDB::20120810
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
